Method: Hanami::API.mount
- Defined in:
- lib/hanami/api.rb
.mount ⇒ Object
Mount a Rack application at the specified path. All the requests starting with the specified path, will be forwarded to the given application.
All the other methods (eg #get) support callable objects, but they restrict the range of the acceptable HTTP verb. Mounting an application with #mount doesn’t apply this kind of restriction at the router level, but let the application to decide.
318 319 320 |
# File 'lib/hanami/api.rb', line 318 def self.mount(...) @router.mount(...) end |